@@ -61,7 +61,7 @@ def load_rbn(path):
     events = []
     file_text = _get_file_text(path)
     if file_text:
-        events = _parse_rbn(file_text)
+        events = parse_rbn(file_text)
     return events
 
 
@@ -353,7 +353,7 @@ def _get_pbn_dealer_index(board, deal):
     return hand_index
 
 
-def _parse_rbn(file_text):
+def parse_rbn(file_text):
     """Populate bridgeobjects objects from a rbn file."""
     events = []
     current_name = ""
